@@ -290,29 +290,3 @@ def amz_repo_init(verbose=False):
         l.end(1)
 
     return
-
-
-# Concise init function after update
-def amz_update_init() -> bool:
-
-    # Copy Data
-    try:
-        # Copy data into .amz dir
-        copy_tree(f'{PKG_DIR}/data', AMZ_DATA_DIR)
-        # Update vars in pre-commit yaml config
-        meta.substitute_in_file('AMZ_DATA_DIR', AMZ_DATA_DIR, f'{AMZ_DATA_DIR}/githooks/config/.pre-commit-config.yaml')
-    except:
-        return False
-
-    # For repo in amz repos, copy config files
-    try:
-        # Fetch all AMZ Repos
-        amz_repos = meta.get_amz_config(['amz_tool_meta', 'repos'])
-
-        for repo in amz_repos:
-            # Copy config files to root of repo: pre-commit, clang-format, yapf, cpplint, and pylint
-            copy_tree(f'{AMZ_DATA_DIR}/githooks/config/', repo)
-    except:
-        return False
-
-    return True
